import _ from 'lodash';
import React, {Component, PropTypes} from 'react';
import {Header, Segment, Table, TableColumn} from 'stardust';

const DOCBLOCK_DESCRIPTION_DEFAULTS = {
  children: 'Body of the component.',
  className: 'Class names for custom styling.',
};

/**
 * Displays a table of a Component's PropTypes.
 */
export default class ComponentProps extends Component {
  static propTypes = {
    /**
     * A single Component's prop info as generated by react-docgen.
     * @type {object} Props info object where keys are prop names and values are prop definitions.
     */
    props: PropTypes.object
  };

  nameRenderer(item) {
    const required = item.required && <span className='ui empty mini red circular label' />;
    return <code>{item.name} {required}</code>;
  }

  defaultValueRenderer(item) {
    const defaultValue = _.get(item, 'defaultValue.value');
    const defaultIsComputed = <span className='ui mini gray circular label'>computed</span>;

    return (
      <div>
        {defaultValue} {_.get(item, 'defaultValue.computed') && defaultIsComputed}
      </div>
    );
  }

  render() {
    const propsDefinition = this.props.props;
    const content = _.map(propsDefinition, (propConfig, propName) => {
      const name = propName;
      const description = _.get(propConfig, 'docBlock.description') || DOCBLOCK_DESCRIPTION_DEFAULTS[name];

      const value = _.get(propConfig, 'type.value');
      let type = _.get(propConfig, 'type.name');
      if (type === 'union') {
        type = _.map(value, (val) => val.name).join('|');
      }
      type = type && `{${type}}`;

      const required = propConfig.required;
      const defaultValue = propConfig.defaultValue;

      return {
        name,
        type,
        value,
        required,
        defaultValue,
        description,
      };
    });

    return (
      <Segment className='basic vertical'>
        <Header.H2 className='ui header'>Props</Header.H2>
        <Table data={content} className='very basic'>
          <TableColumn dataKey='name' cellRenderer={this.nameRenderer} />
          <TableColumn dataKey='type' />
          <TableColumn dataKey='defaultValue' cellRenderer={this.defaultValueRenderer} />
          <TableColumn dataKey='description' />
        </Table>
      </Segment>
    );
  }
}
